from requests import get
from bs4 import BeautifulSoup

url = 'https://www.nqlegal.com.au/townsville-conveyancing-solicitors/queensland-councils-shires/' # Using this because the official government directory returns a 404 (very professional)

def get_councils():
    _councils = []
    rows = BeautifulSoup(get(url).text, 'lxml').find_all('table')[-1].find_all('tr')
    for row in rows[1:]:
        _councils.append(row.find('td').text)
    return(_councils)

councils = get_councils()


from requests import get
from bs4 import BeautifulSoup

url = 'https://www.viccouncils.asn.au/find-your-council/council-contacts-list'

def get_councils():
    _council_names = []
    rows = BeautifulSoup(get(url).text, 'lxml').find('table', {'id': 'table19340'}).find_all('tr')
    for row in rows:
        _council_names.append(row.find('p').text)
    return(_council_names)

councils = get_councils()


from sys import int_info
from requests import get
from bs4 import BeautifulSoup

url = 'https://www.olg.nsw.gov.au/public/local-government-directory/'

def get_councils():
    council_list = []
    _councils_html = BeautifulSoup(get(url).text, 'lxml').find('ul', {'class': 'accordion accordion-child'}).find_all('li')
    for i in _councils_html:
        council_list.append(i.find('a').text)
    return(council_list)

councils = get_councils()


from requests import get
from bs4 import BeautifulSoup

url = 'https://www.lga.sa.gov.au/sa-councils/councils-listing'

def get_councils():
    council_list = []
    _list = BeautifulSoup(get(url).text, 'lxml').find('div', id='content_container_538648')
    for entry in _list.find_all('li', {'class': 'sacouncils-listing-item'}):
        council_list.append(entry.text.strip())
    return council_list

councils = get_councils()